Git integration for commit info and file history
Structs
- File
GitInfo - Git info for a specific file
- GitInfo
Functions
- get_
file_ git_ info - Get git info for a specific file or directory (last commit that modified it) For directories, finds the most recent commit that modified any file within
- get_
git_ info - make_
git_ branch - make_
git_ commit_ message - make_
git_ commit_ timestamp - make_
git_ hash - make_
git_ is_ dirty - make_
git_ short_ hash - register_
git_ functions