Module tracker

Module tracker 

Build dependency tracker for incremental builds

Structs

AssetRef
Asset reference extracted from HTML (script src, link href, img src, etc.)
BuildTracker
CachedDeps
FileState
MemoKey

Functions

extract_html_asset_refs
Extract asset references from HTML content. Looks for: script src, link href, img src, video src, audio src, source src
extract_markdown_asset_refs
Extract image references from markdown content Looks for: alt and alt
hash_content
hash_str
resolve_url_to_source
Map a URL path (e.g., “/js/editor.js”) to a source path (e.g., “static/js/editor.js”) Uses the writes map to find what source file produced the output

Type Aliases

SharedTracker