pub struct BuildTracker { /* private fields */ }Implementations
Sourceimpl BuildTracker
impl BuildTracker
pub fn new() -> Self
pub fn disabled() -> Self
pub fn is_enabled(&self) -> bool
pub fn record_read(&self, path: PathBuf, content: &[u8])
Sourcepub fn record_read_async(&self, path: PathBuf, content: &[u8])
pub fn record_read_async(&self, path: PathBuf, content: &[u8])
Record a file read directly to shared state (for async contexts like tokio) Use this instead of record_read when running in async tasks where thread-locals won’t be merged properly
pub fn record_read_with_hash(&self, path: PathBuf, hash: u64, mtime: SystemTime)
pub fn record_write(&self, path: PathBuf, content: &[u8])
Sourcepub fn record_write_async(&self, path: PathBuf, content: &[u8])
pub fn record_write_async(&self, path: PathBuf, content: &[u8])
Record a file write directly to shared state (for async contexts like tokio) Use this instead of record_write when running in async tasks where thread-locals won’t be merged properly
pub fn merge_thread_locals(&self)
pub fn merge_all_threads(&self)
pub fn memo_get( &self, function: &'static str, input_hash: u64, ) -> Option<Vec<u8>>
pub fn memo_set(&self, function: &'static str, input_hash: u64, output: Vec<u8>)
pub fn get_reads(&self) -> HashMap<PathBuf, FileState>
pub fn get_writes(&self) -> HashMap<PathBuf, FileState>
pub fn clear(&self)
Sourcepub fn clear_writes(&self)
pub fn clear_writes(&self)
Clear only writes (for incremental rebuilds)
Sourcepub fn record_html_refs(&self, page_path: PathBuf, refs: Vec<AssetRef>)
pub fn record_html_refs(&self, page_path: PathBuf, refs: Vec<AssetRef>)
Record HTML asset references for a rendered page
Sourcepub fn get_pages_for_asset(&self, asset_path: &PathBuf) -> Vec<PathBuf>
pub fn get_pages_for_asset(&self, asset_path: &PathBuf) -> Vec<PathBuf>
Get pages that reference a given asset (by source path)
Sourcepub fn is_asset_referenced(&self, asset_path: &PathBuf) -> bool
pub fn is_asset_referenced(&self, asset_path: &PathBuf) -> bool
Check if an asset is referenced by any page
Sourcepub fn get_asset_to_pages(&self) -> HashMap<PathBuf, Vec<PathBuf>>
pub fn get_asset_to_pages(&self) -> HashMap<PathBuf, Vec<PathBuf>>
Get reverse mapping of assets to pages
pub fn get_changed_files(&self, cached: &CachedDeps) -> Vec<PathBuf>