Build dependency tracker for incremental builds
Structs
- Asset
Ref - Asset reference extracted from HTML (script src, link href, img src, etc.)
- Build
Tracker - Cached
Deps - File
State - MemoKey
Functions
- extract_
html_ asset_ refs - Extract asset references from HTML content. Looks for: script src, link href, img src, video src, audio src, source src
- extract_
markdown_ asset_ refs - Extract image references from markdown content Looks for: alt and alt
- hash_
content - hash_
str - resolve_
url_ to_ source - Map a URL path (e.g., “/js/editor.js”) to a source path (e.g., “static/js/editor.js”) Uses the writes map to find what source file produced the output